@@ -40,6 +40,12 @@ class TestBatch:
         self._test_run_id = test_run_id
         self._test_type = test_type
 
+    def __repr__(self) -> str:
+        """Return a string representation of the TestBatch."""
+        return (
+            f"TestBatch(test_run_id={self._test_run_id}, test_type={self._test_type})"
+        )
+
     @property
     def test_run_id(self) -> str:
         """Return the test run id of the test batch."""
